==> tkscanfax-1.1.4%2C1.tbz: lib/tkscanfax1/scan-init.tcl <==
#----------------------------------------------------------------
# StartUp
#----------------------------------------------------------------

# set locale and read messagess
set fax(libdir) $c(libdir)
set fax(progname) ""
set fax(version) ""
set fax(date) ""
set fax(faxagent) ""
set fax(locale) ""
set fax(userconfigfile) ""
set fax(pbookgroupfile) ""
set fax(docdir) $fax(libdir)/doc


# Read files.

set tkscan_files "
	fax-about
	fax-conf
        scan-about
	scan-drivers/$scanner_driver
        scan-conf
	scan-lib
	scan-scan
	scan-out
	scan-scanwin
	scan-file
        scan-win
"
foreach i $tkscan_files { source $c(libdir)/$i.tcl }

  set envlocale {}
  if { $fax(locale) == {}  } {
	foreach i  {LANGUAGE LC_ALL LANG } {
		if { [ info exists  env($i) ] } { set envlocale $env($i) } 
	}
      if  { [ string length $envlocale ] >= 2 } {
          set fax(locale) [ string range $envlocale 0 1 ]
      }
  }
  # set locale and read messages
  foreach i { scan-msg.tcl } {
     source $fax(docdir)/C/$i
  }
  if { $fax(locale)=="" } { set fax(locale) "C" }
  if { $fax(locale)!="C"} {
	set localemsgdir $fax(docdir)/$fax(locale)
	foreach i { scan-msg.tcl } {
	    if [file exists $localemsgdir/$i] { source $localemsgdir/$i }
	}
  }

# Let's start.

eval destroy [winfo child .]
wm title . "TkScan"

set s(unit)	mm

# The user configuration file, if exists, overwrites the above assignments.

if [file exists $c(userconf)] {source $c(userconf)}


# Initialization of some variables

set s(nrect)	0
set s(runscan)	0
set s(curscan)	0
set s(stop)	0


# Launch main window

Window_Scan {}
Preview_Canvas
image create photo preview -data {}
set ip [expr $s(o)-1]
$w(prev) create image $ip $ip -image preview -anchor nw
set s(rect0) [$w(prev) create rectangle 0 0 0 0 -width 1 -outline $l(c2)]
settop $s(o) $s(o)
setbottom $s(maxpwidth) $s(maxpheight)
setunit $s(unit)
setmode $s(mode)
stat_text "TkScan $c(version)"

==> tkscanfax-1.1.8_1%2C1.tbz: lib/tkscanfax1/scan-init.tcl <==
#----------------------------------------------------------------
# StartUp
#----------------------------------------------------------------

# set locale and read messagess
set fax(libdir) $c(libdir)
set fax(progname) ""
set fax(version) ""
set fax(date) ""
set fax(faxagent) ""
set fax(locale) ""
set fax(userconfigfile) ""
set fax(pbookgroupfile) ""
set fax(docdir) $fax(libdir)/doc


# Read files.

set tkscan_files "
	fax-about
	fax-conf
        scan-about
	scan-drivers/$scanner_driver
        scan-conf
	scan-lib
	scan-scan
	scan-out
	scan-scanwin
	scan-file
        scan-win
"
foreach i $tkscan_files { source $c(libdir)/$i.tcl }

  set envlocale {}
  if { $fax(locale) == {}  } {
	foreach i  {LANGUAGE LC_ALL LANG } {
		if { [ info exists  env($i) ] } { set envlocale $env($i) } 
	}
      if  { [ string length $envlocale ] >= 2 } {
		set fax(locale) $envlocale
      #    set fax(locale) [ string range $envlocale 0 1 ]
       }
  }
  # set locale and read messages
  foreach i { scan-msg.tcl } {
     source $fax(docdir)/C/$i
  }
  if { $fax(locale)=="" } { set fax(locale) "C" }
  if { $fax(locale)!="C"} {
	set fax(locale1) [lindex [split $fax(locale) {_}] 0]
	set fax(locale2) [lindex [split $fax(locale) {.}] 0]
	foreach d "$fax(locale1) $fax(locale2) $fax(locale)" {
	  set localemsgdir $fax(docdir)/$d
	  foreach i { scan-msg.tcl } {
	    if [file exists $localemsgdir/$i] { source $localemsgdir/$i }
	   }
	}
  }
# Let's start.

eval destroy [winfo child .]
wm title . "TkScan"

set s(unit)	mm

# The user configuration file, if exists, overwrites the above assignments.

if [file exists $c(userconf)] {source $c(userconf)}


# Initialization of some variables

set s(nrect)	0
set s(runscan)	0
set s(curscan)	0
set s(stop)	0


# Launch main window

Window_Scan {}
Preview_Canvas
image create photo preview -data {}
set ip [expr $s(o)-1]
$w(prev) create image $ip $ip -image preview -anchor nw
set s(rect0) [$w(prev) create rectangle 0 0 0 0 -width 1 -outline $l(c2)]
settop $s(o) $s(o)
setbottom $s(maxpwidth) $s(maxpheight)
setunit $s(unit)
setmode $s(mode)
stat_text "TkScan $c(version)"
